CShake128Core

Struct CShake128Core 

pub struct CShake128Core { /* private fields */ }
cSHAKE128 core hasher.

Implementations

Source

impl CShake128Core

pub fn new_with_function_name( function_name: &[u8], customization: &[u8], ) -> Self

Creates a new CSHAKE instance with the given function name and customization.

Note that the function name is intended for use by NIST and should only be set to values defined by NIST. You probably don’t need to use this function.